@@ -12,6 +12,7 @@ trainControl <- function(method = "boot",
                          ICAcomp = 3,
                          k = 5,
                          index = NULL,
+                         timingSamps = 0,
                          workers = 1,
                          predictionBounds = rep(FALSE, 2),
                          computeFunction = lapply,
@@ -34,6 +35,7 @@ trainControl <- function(method = "boot",
        ICAcomp = ICAcomp,
        k = k,
        index = index,
+       timingSamps = timingSamps,
        workers = workers,
        predictionBounds = predictionBounds,
        computeFunction = computeFunction,
